@@ -143,9 +143,9 @@ class LDAP(object):
                 mu['mail'] = user.get('mail')
                 mu['location'] = user.get('streetAddress')
                 mu['ip_phone'] = user.get('ipPhone')
-                #TODO inject user profile in session if mongo is None
                 if self.mongo is not None:
                     self.mongo.db.users.save(mu), mu['full_name']
+                self.mu = mu
 
             return True
 
@@ -161,7 +161,8 @@ class LDAP(object):
         if request.method == 'POST':
             if "username" in request.form and "password" in request.form:
                 if self.ldap_login(request.form['username'], request.form['password']):
-                    session['username'] = request.form['username']
+                    for i in self.mu.keys():
+                        session[i] = self.mu[i]
                     return redirect(url_for(self.app.config['LDAP_SUCCESS_REDIRECT']))
                 else:
                     return render_template(self.app.config['LDAP_LOGIN_TEMPLATE'])
